@@ -11,7 +11,7 @@ import sys
 import shutil
 import tempfile
 from os.path import abspath, dirname, isfile, join
-from subprocess import check_call
+from subprocess import check_call, check_output
 
 from constructor.construct import ns_platform
 from constructor.install import name_dist
@@ -141,15 +141,22 @@ def make_nsi(info, dir_path):
 
 
 def verify_nsis_install():
+    print("Checking for '%s'" % MAKENSIS_EXE)
     if not isfile(MAKENSIS_EXE):
         sys.exit("""
 Error: no file %s
     please make sure nsis is installed:
     > conda install -n root nsis
 """ % MAKENSIS_EXE)
-    untgz_dll = join(sys.prefix, 'NSIS', 'Plugins', 'untgz.dll')
+    out = check_output([MAKENSIS_EXE, '/VERSION'])
+    out = out.decode('utf-8').strip()
+    print("NSIS version: %s" % out)
+    if 'v3.' in out:
+        untgz_dll = join(sys.prefix, 'NSIS', 'Plugins', 'x86-ansi', 'untgz.dll')
+    else:
+        untgz_dll = join(sys.prefix, 'NSIS', 'Plugins', 'untgz.dll')
     if not isfile(untgz_dll):
-         sys.exit("Error: no file %s")
+         sys.exit("Error: no file %s" % untgz_dll)
 
 
 def create(info):
